# -*- coding: utf-8 -*-
OFFICIAL_KIARA_PLUGINS = [
    "core_types",
    "tabular",
    "onboarding",
    "network_analysis",
    "language_processing",
    "html",
    "streamlit",
]
